<?php
// src/OgGitBundle/Controller/OgGitController.php

namespace App\OgGitBundle\Controller;
use OpenApi\Annotations as OA;
use Psr\Log\LoggerInterface;
use App\OgGitBundle\Service\CurlRequestService;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\Messenger\MessageBusInterface;
use Symfony\Component\DependencyInjection\ParameterBag\ParameterBagInterface;
use Symfony\Contracts\HttpClient\HttpClientInterface;
use Exception;


class OgGitController
{
    private $logger;
    /**
     * @OA\Info(title="OgGit API", version="1.0")
     */

    private $curlRequestService;
    private $httpClient;
    private $params;
    public function __construct(CurlRequestService $curlRequestService, LoggerInterface $logger, HttpClientInterface $httpClient, ParameterBagInterface $params)
    {
        $this->curlRequestService = $curlRequestService;
        $this->logger = $logger;
        $this->httpClient = $httpClient;
        $this->params = $params;
    }




/**
 * @Route("/oggit/v1/status", name="getStatus", methods={"GET"})
 * @OA\Get(
 *     path="/oggit/v1/status",
 *     summary="Get oggit status",
 *     @OA\Response(
 *         response=200,
 *         description="Status retrieved successfully",
 *         @OA\JsonContent(
 *             type="object",
 *             @OA\Property(property="message", type="string")
 *         )
 *     )
 * )
 */
public function getStatus(): Response
{
    $response = [
        'message' => 'Todo OK'
    ];

    return new JsonResponse($response, 200);
}


    /**
     * @Route("/oggit/v1/repositories", methods={"GET"})
     * @OA\Get(
     *     path="/oggit/v1/repositories",
     *     summary="Obtener un listado de todos los repositorios alojados en el servidor OG",
     *     tags={"Repositories"},
     *     @OA\Response(
     *         response=200,
     *         description="Lista de repositorios obtenida con éxito",
     *         @OA\JsonContent(
     *             type="array",
     *             @OA\Items(
     *                 type="object",
     *                 @OA\Property(property="id", type="string", description="ID del repositorio"),
     *                 @OA\Property(property="name", type="string", description="Nombre del repositorio"),
     *                 @OA\Property(property="createdAt", type="string", format="date-time", description="Fecha de creación del repositorio"),
     *                 @OA\Property(property="lastModified", type="string", format="date-time", description="Última modificación del repositorio")
     *             )
     *         )
     *     ),
     *     @OA\Response(
     *         response=500,
     *         description="Error interno del servidor"
     *     )
     * )
     */
    public function getRepositories(): JsonResponse
    {
        // Lógica para obtener los repositorios (por ahora, devolvemos un mensaje de prueba)
        return new JsonResponse([
            [
                'id' => '1',
                'name' => 'Repositorio 1',
                'createdAt' => '2024-09-12T10:00:00Z',
                'lastModified' => '2024-09-12T12:00:00Z'
            ],
            [
                'id' => '2',
                'name' => 'Repositorio 2',
                'createdAt' => '2024-09-11T08:30:00Z',
                'lastModified' => '2024-09-12T09:00:00Z'
            ]
        ], 200);
    }

    /**
     * @Route("/oggit/v1/repositories/{id}", methods={"DELETE"})
     * @OA\Delete(
     *     path="/oggit/v1/repositories/{id}",
     *     tags={"Repositories"},
     *     summary="Eliminar un repositorio",
     *     @OA\Parameter(
     *         name="id",
     *         in="path",
     *         required=true,
     *         description="ID del repositorio a eliminar",
     *         @OA\Schema(type="string")
     *     ),
     *     @OA\Response(
     *         response=204,
     *         description="Repositorio eliminado exitosamente"
     *     ),
     *     @OA\Response(
     *         response=404,
     *         description="Repositorio no encontrado"
     *     ),
     *     @OA\Response(
     *         response=500,
     *         description="Error en el servidor"
     *     )
     * )
     */
    public function deleteRepository($id): JsonResponse
    {
        return new JsonResponse([
            'message' => "Llamando a la función deleteRepository para eliminar el repositorio con ID $id."
        ], 204);
    }


    /**
     * @Route("/oggit/v1/repositories/{id}/branches", methods={"GET"})
     * @OA\Get(
     *     path="/oggit/v1/repositories/{id}/branches",
     *     summary="Obtener las ramas de un repositorio",
     *     tags={"Branches"},
     *     @OA\Parameter(
     *         name="id",
     *         in="path",
     *         required=true,
     *         description="ID del repositorio",
     *         @OA\Schema(type="string")
     *     ),
     *     @OA\Response(
     *         response=200,
     *         description="Operación exitosa",
     *         @OA\JsonContent(
     *             type="object",
     *             @OA\Property(property="message", type="string")
     *         )
     *     )
     * )
     */
    public function getBranches($id): JsonResponse
    {
        return new JsonResponse([
            'message' => "Llamando a la función getBranches con estos parámetros: id = $id"
        ], 200);
    }



    /**
     * @Route("/oggit/v1/repositories/{repoId}/branches/{branchId}", methods={"DELETE"})
     * @OA\Delete(
     *     path="/oggit/v1/repositories/{repoId}/branches/{branchId}",
     *     summary="Eliminar una rama de un repositorio",
     *     tags={"Branches"},
     *     @OA\Parameter(
     *         name="repoId",
     *         in="path",
     *         required=true,
     *         description="ID del repositorio",
     *         @OA\Schema(type="string")
     *     ),
     *     @OA\Parameter(
     *         name="branchId",
     *         in="path",
     *         required=true,
     *         description="ID de la rama a eliminar",
     *         @OA\Schema(type="string")
     *     ),
     *     @OA\Response(
     *         response=204,
     *         description="Rama eliminada exitosamente"
     *     ),
     *     @OA\Response(
     *         response=404,
     *         description="Repositorio o rama no encontrada"
     *     ),
     *     @OA\Response(
     *         response=500,
     *         description="Error en el servidor"
     *     )
     * )
     */
    public function deleteBranch($repoId, $branchId): JsonResponse
    {
        return new JsonResponse([
            'message' => "Llamando a la función deleteBranch para eliminar la rama con ID $branchId del repositorio con ID $repoId."
        ], 204);
    }

}